# NAME:
#	csh.cshrc - global initialization for csh
#
# DESCRIPTION:
#	This file is processed by each invocation of /bin/csh
#	The idea is to provide central management of the
#	operating environment for C-shell users.  While some
#	versions of the C-shell will automatically process this
#	file, others require the users $HOME/.cshrc file to
#	contain the line:
#		source /etc/csh.cshrc
#	The user's .cshrc file can of course override any of
#	these defaults if needed.
#
# SEE ALSO:
#	$HOME/.cshrc
#	/etc/csh.login
#
# BUGS:
#	I stopped using csh in about 1990, so I doubt that this
#	produces the same environment as my /etc/profile and
#	/etc/ksh.kshrc
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: csh.cshrc,v 1.2 2001/08/30 09:55:53 sjg Exp $
#
#	@(#)Copyright (c) 1991 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 

if ( $?prompt ) then
	if (! $?HOSTNAME ) setenv HOSTNAME `uname -n`
	setenv USER `whoami`
	set prompt="${USER}@${HOSTNAME}:\!% "
	set history=128
	set ignoreof
#	set noclobber
	set filec
	# basename is not good enough for Solaris
	setenv tty `tty | sed 's,/dev/,,'`

	alias ls	'ls -CF'
	alias h		'history | more'
# following is for sun386i only
#	alias extras    'source /usr/bin/friendly_aliases'
 
	set noglob
	# if we are a window'd terminal update the title bar
	switch ($term)
	case sun*:
		setenv ILS "]L"
		setenv ILE "\"
		setenv WLS "]L"
		setenv WLE $ILE
		breaksw
	case xterm:
		if ($?DISPLAY) then
			setenv ILS "]1;"
			setenv ILE ""
			setenv WLS "]2;"
			setenv WLE $ILE
		endif
		breaksw
	default:
		breaksw
	endsw
	if ($?WLS) then
		alias ilabel 	'echo -n "${ILS}\!*${ILE}"'
		alias label	'echo -n "${WLS}\!*${WLE}"'
		alias stripe	'label $USER@$HOSTNAME ($tty) - `pwd`'
		alias istripe	'ilabel $USER@$HOSTNAME'
		alias cd	'cd \!*; stripe'

		foreach cmd (telnet rlogin ftp su kermit stelnet tip)
			eval "alias $cmd '$cmd \\!*; stripe; istripe'"
		end

		switch ($tty)
		case tty[pqrs]*:
			istripe
			stripe
			breaksw
		endsw
	endif
	unset noglob
endif


