:
# NAME:
#	ksh.kshrc - global initialization for ksh 
#
# DESCRIPTION:
#	Each invocation of /bin/ksh processes the file pointed
#	to by $ENV (usually $HOME/.kshrc).
#	This file is intended as a global .kshrc file for the
#	Korn shell.  A user's $HOME/.kshrc file simply requires
#	the line:
#		. /etc/ksh.kshrc
#	at or near the start to pick up the defaults in this
#	file which can then be overridden as desired.
#
# SEE ALSO:
#	$HOME/.kshrc
#	ksh.cdhist
#	ksh.xenv
#
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: ksh.kshrc,v 1.38 2007/10/07 06:47:12 sjg Exp $
#
#	@(#)Copyright (c) 1991 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 

set +u

# $_SOURCE_SH . source.sh
_SOURCE_SH=:

_source() {
	f=$1; shift

	for d in `IFS=:; echo ${*:-$PATH}`
	do
		[ -s $d/$f ] || continue
		. $d/$f
		break
	done
}

case "$-" in
*i*)	# we are interactive
	# Set PS1P=': ' in .profile if you want a prompt
	# that can be cut/pasted without harm.
	# The space after the : is necessary.
	#PS1P=${PS1P:-': '}
	if [ -w / ]; then
		PS1S="#${PS1P:+;}"
	else
		PS1S="${PS1P:+;}"
		PS1S="${PS1S:-\$}"
	fi

	set -o emacs		# doesn't everyone prefer it?

	# Some posix /bin/sh will come here and die...
	if [ "x$RANDOM" != "x$RANDOM" ]; then
		if [ "$BASH" ]; then
		        KSH_VERSION=BASH
		else
        		PS1S=":!$PS1S"
		fi

		# Assume we want cd history
		cdhist=ksh.cdhist
		case "$KSH_VERSION" in
		BASH)	;;
		*PD*)	# PD ksh
			case "$KSH_VERSION" in
			*v4.*)	cdhist=
			esac
			case "$TERM" in
			pc3|xterm*|dtterm*)
				# bind arrow keys
				bind '^[['=prefix-2
				bind '^XA'=up-history
				bind '^XB'=down-history
				bind '^XC'=forward-char
				bind '^XD'=backward-char
				;;
			esac
			;;
		*)	# real ksh ?
			set -o trackall
			case "$TERM" in
			vt*|xterm*|dtterm*)
				# Kevin Gallagher in comp.emacs!
				alias	 __A= # up arrow
				alias	 __B= # down arrow
				alias	 __C= # right arrow
				alias	 __D= # left arrow
				;;
			esac
			;;
		esac
		if [ "$cdhist" ]; then
			_source $cdhist $HOME/etc $ETC /etc
		fi
        fi
        
	# pickup all the window decoration stuff
	# sets USER et al too.
	_source ksh.xenv $HOME/etc $ETC /etc
	# if you always want user@host in prompt
	# set and export PUSER in .profile
	PUSER=${PUSER:-$USER@$HOST}
	PROMPT="$PS1P$PUSER$PS1S "
	PPROMPT="$PS1P$PUSER:\${PWD##*?/}$PS1S "

	PS1="$PROMPT"
	case "$PS1" in
	:*) PS2="	";;
	esac
        ;;
*)	# non-interactive
        ;;
esac
# commands for both interactive and non-interactive shells
$_ADD_PATH_SH _source add_path.sh $HOME/etc $ETC /etc
# site customizations
_source ksh.site  $HOME/etc $ETC /etc
