#!/bin/sh
#
# NAME:
#	shar.sh - portable shell archive maker.
#
# SYNOPSIS:
#	shar.sh [-a "script"] "file" [...]
#
# DESCRIPTION:
#	This script will create shell archive, that will create
#	needed directories as well as preserving execute
#	permissions.
#
#	Options:
#
#	-a "script"
#		Append "script" to the end of the archive to do
#		special processing when it is unpacked.  Used by
#		uumail.sh and others.
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: shar.sh,v 1.7 2001/08/30 09:55:59 sjg Exp $
#
#	@(#) Copyright (c) 1992 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

a_script=
test x$1 = x-a && { a_script=$2; shift; shift; }

cat <<!EOM
#!/bin/sh
# This is a shell archive.
# remove everything above the "#!/bin/sh" line
# and feed to /bin/sh
# Use -c option to overwrite existing files
#
# Contents: 
`echo $* | sed -e 's/^/#	/' -e 's/ /\\
#	/g'`
#
# packed by: <`logname`@`hostname`> on `date`
#
PATH=/bin:/usr/bin:/usr/ucb ; export PATH
!EOM

# list of dirs we have "made"
dirs=""

split () { (IFS="$1"; shift; set -- $*; echo "$@"); }

# modified from sh_funcs.sh
mkdirs ()
{
  for _path in $*
  do
    _dirs=`split / $_path`
    case "$_path" in
    /*)
      _path="/";;
    *)
      _path="";;
    esac
    for _dir in $_dirs
    do
      case "$_path" in
      "")
        _path=$_dir;;
      /)
        _path=/$_dir;;
      *)
        _path=$_path/$_dir;;
      esac
      case "$_path" in
      .)	continue;;
      esac
      echo "test -d $_path || mkdir $_path"
    done
  done
}

# now do it...
for f in $*
do
  case "$f" in
  */*)
    dir=`dirname $f`
    case "$dirs" in
    *" $dir "*) ;;
    *)
      dirs="$dirs $dir "
      echo echo shar: making path \"$dir\"
      mkdirs $dir
      ;;
    esac
    ;;
  esac
  if [ -x $f ]; then
    mod="chmod +x $f"
  else
    mod=""
  fi
  sz=`wc -c < $f`
  cat << !EOC
if test -f $f -a x\$1 != x-c ; then
  echo shar: Will not over-write existing file \"$f\"
else
  echo shar: Extracting \"$f\" \($sz characters\)
  sed 's/^X//' > $f << '!EOF'
!EOC
  sed 's/^/X/' $f
  cat << !EOC
!EOF
  if test $sz -ne \`wc -c < $f\`; then
    echo shar: \"$f\" unpacked with wrong size!
  fi
  $mod
fi
!EOC
done
test "$a_script" && cat $a_script
echo "exit 0"
exit 0
